Module: TestingBot::Resources::Builds

Included in:
Api
Defined in:
lib/testingbot/resources/builds.rb

Overview

Endpoints under /builds.

Instance Method Summary collapse

Instance Method Details

#delete_build(build_identifier) ⇒ Object



16
17
18
# File 'lib/testingbot/resources/builds.rb', line 16

def delete_build(build_identifier)
  delete("/builds/#{build_identifier}")
end

#get_build(build_identifier, params = {}) ⇒ Object

params accepts optional offset/count/skip_fields query params. The build identifier maps to a wildcard route, so it is passed through unescaped to preserve any slashes it may contain.



12
13
14
# File 'lib/testingbot/resources/builds.rb', line 12

def get_build(build_identifier, params = {})
  get("/builds/#{build_identifier}#{query(params)}")
end

#get_builds(offset = 0, count = 10) ⇒ Object



5
6
7
# File 'lib/testingbot/resources/builds.rb', line 5

def get_builds(offset = 0, count = 10)
  get("/builds#{query(:offset => offset, :count => count)}")
end