Module: TestingBot::Resources::Platform
- Included in:
- Api
- Defined in:
- lib/testingbot/resources/platform.rb
Overview
Browser, device and configuration endpoints.
Instance Method Summary collapse
- #get_available_devices ⇒ Object
- #get_browsers ⇒ Object
-
#get_device(device_id) ⇒ Object
Fetch a single physical device by its numeric ID.
-
#get_devices(platform = nil, web = nil) ⇒ Object
Optionally filter server-side by platform and/or web capability.
-
#get_ip_ranges ⇒ Object
List the IP ranges TestingBot tests originate from (firewall allow-listing).
Instance Method Details
#get_available_devices ⇒ Object
14 15 16 |
# File 'lib/testingbot/resources/platform.rb', line 14 def get_available_devices get("/devices/available") end |
#get_browsers ⇒ Object
5 6 7 |
# File 'lib/testingbot/resources/platform.rb', line 5 def get_browsers get("/browsers") end |
#get_device(device_id) ⇒ Object
Fetch a single physical device by its numeric ID.
19 20 21 |
# File 'lib/testingbot/resources/platform.rb', line 19 def get_device(device_id) get("/devices/#{escape(device_id)}") end |
#get_devices(platform = nil, web = nil) ⇒ Object
Optionally filter server-side by platform and/or web capability.
10 11 12 |
# File 'lib/testingbot/resources/platform.rb', line 10 def get_devices(platform = nil, web = nil) get("/devices#{query(:platform => platform, :web => web)}") end |
#get_ip_ranges ⇒ Object
List the IP ranges TestingBot tests originate from (firewall allow-listing).
24 25 26 |
# File 'lib/testingbot/resources/platform.rb', line 24 def get_ip_ranges get("/configuration/ip-ranges") end |